@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2022 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,11 +29,11 @@
 #endif
 
 #include "hipblas.h"
+#include "hipblas_test.hpp"
 #include "utility.h"
 #include <chrono>
 #include <cstdlib>
 #include <cstring>
-#include <new>
 #include <stdexcept>
 #include <stdlib.h>
 
@@ -54,9 +54,19 @@ namespace fs = std::experimental::filesystem;
 #include <unistd.h>
 #endif
 
+// global for device memory padding see d_vector.hpp
+size_t g_DVEC_PAD = 4096;
+
+void d_vector_set_pad_length(size_t pad)
+{
+    g_DVEC_PAD = pad;
+}
+
 hipblas_rng_t hipblas_rng(69069);
 hipblas_rng_t hipblas_seed(hipblas_rng);
 
+int64_t c_i32_overflow = int64_t(std::numeric_limits<int32_t>::max()) + 1; // 2147483648
+
 template <>
 char type2char<float>()
 {
@@ -211,21 +221,108 @@ hipblasLocalHandle::hipblasLocalHandle(const Arguments& arg)
     {
         throw std::runtime_error(hipblasStatusToString(status));
     }
+
+    // memory guard control, with multi-threading should not change values across threads
+    d_vector_set_pad_length(arg.pad);
 }
 
 hipblasLocalHandle::~hipblasLocalHandle()
 {
     if(m_memory)
     {
-        CHECK_HIP_ERROR(hipFree(m_memory));
+        // m_memory never used currently
+        auto hipStatus = hipFree(m_memory);
+        if(hipStatus != hipSuccess)
+        {
+            std::cerr << "error freeing hip memory in hipblasLocalHandle: "
+                      << hipGetErrorString(hipStatus) << "\n";
+        }
     }
     hipblasStatus_t status = hipblasDestroy(m_handle);
     if(status != HIPBLAS_STATUS_SUCCESS)
     {
-        printf("hipblasDestroy error!\n");
+        std::cerr << "hipblasDestroy error: " << hipblasStatusToString(status) << "\n";
+#ifdef GOOGLE_TEST
+        EXPECT_EQ(status, HIPBLAS_STATUS_SUCCESS);
+#endif
     }
 }
 
+/*******************************************************************************
+ * \brief convert hipError_t to hipblasStatus_t
+ * TODO - enumerate library calls to hip runtime, enumerate possible errors from those calls
+ ******************************************************************************/
+hipblasStatus_t hipblas_internal_convert_hip_to_hipblas_status(hipError_t status)
+{
+    switch(status)
+    {
+    // success
+    case hipSuccess:
+        return HIPBLAS_STATUS_SUCCESS;
+
+    // internal hip memory allocation
+    case hipErrorMemoryAllocation:
+    case hipErrorLaunchOutOfResources:
+        return HIPBLAS_STATUS_MAPPING_ERROR;
+
+    // user-allocated hip memory
+    case hipErrorInvalidDevicePointer: // hip memory
+        return HIPBLAS_STATUS_MAPPING_ERROR;
+
+    // user-allocated device, stream, event
+    case hipErrorInvalidDevice:
+    case hipErrorInvalidResourceHandle:
+        return HIPBLAS_STATUS_HANDLE_IS_NULLPTR;
+
+    // library using hip incorrectly
+    case hipErrorInvalidValue:
+        return HIPBLAS_STATUS_INTERNAL_ERROR;
+
+    // hip catch find matching ISA
+    case hipErrorNoBinaryForGpu:
+        return HIPBLAS_STATUS_ARCH_MISMATCH;
+
+    // hip runtime failing
+    case hipErrorNoDevice: // no hip devices
+    case hipErrorUnknown:
+    default:
+        return HIPBLAS_STATUS_UNKNOWN;
+    }
+}
+
+hipblasStatus_t hipblas_internal_convert_hip_to_hipblas_status_and_log(hipError_t status)
+{
+    hipblasStatus_t lib_status = hipblas_internal_convert_hip_to_hipblas_status(status);
+    std::cerr << "hipBLAS error from hip error code: '" << hipGetErrorName(status) << "':" << status
+              << std::endl;
+    return lib_status;
+}
+
+std::string getArchString()
+{
+    int  device;
+    auto hipStatus = hipGetDevice(&device);
+    if(hipStatus != hipSuccess)
+    {
+        std::cerr << "Error with hipGetDevice: " << hipGetErrorString(hipStatus);
+        return "";
+    }
+
+    hipDeviceProp_t deviceProperties;
+    hipStatus = hipGetDeviceProperties(&deviceProperties, device);
+    if(hipStatus != hipSuccess)
+    {
+        std::cerr << "Error with hipGetDeviceProperties: " << hipGetErrorString(hipStatus);
+        return "";
+    }
+
+    // strip out xnack/ecc from name
+    std::string deviceFullString(deviceProperties.gcnArchName);
+    std::string deviceString = deviceFullString.substr(0, deviceFullString.find(":"));
+
+    return deviceString;
+}
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -321,50 +418,94 @@ void set_device(int device_id)
 /*******************************************************************************
  * GPU architecture-related functions
  ******************************************************************************/
-
-int getArch()
+hipblasClientProcessor getArch()
 {
-    int device;
-    CHECK_HIP_ERROR(hipGetDevice(&device));
+    int  device;
+    auto hipStatus = hipGetDevice(&device);
+    if(hipStatus != hipSuccess)
+    {
+        std::cerr << "Error with hipGetDevice: " << hipGetErrorString(hipStatus);
+        return static_cast<hipblasClientProcessor>(0);
+    }
+
     hipDeviceProp_t deviceProperties;
-    CHECK_HIP_ERROR(hipGetDeviceProperties(&deviceProperties, device));
-    return deviceProperties.gcnArch;
+    hipStatus = hipGetDeviceProperties(&deviceProperties, device);
+    if(hipStatus != hipSuccess)
+    {
+        std::cerr << "Error with hipGetDeviceProperties: " << hipGetErrorString(hipStatus);
+        return static_cast<hipblasClientProcessor>(0);
+    }
+
+    // strip out xnack/ecc from name
+    std::string deviceFullString(deviceProperties.gcnArchName);
+    std::string deviceString = deviceFullString.substr(0, deviceFullString.find(":"));
+
+    if(deviceString.find("gfx803") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx803;
+    }
+    else if(deviceString.find("gfx900") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx900;
+    }
+    else if(deviceString.find("gfx906") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx906;
+    }
+    else if(deviceString.find("gfx908") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx908;
+    }
+    else if(deviceString.find("gfx90a") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx90a;
+    }
+    else if(deviceString.find("gfx940") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx940;
+    }
+    else if(deviceString.find("gfx941") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx941;
+    }
+    else if(deviceString.find("gfx942") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx942;
+    }
+    else if(deviceString.find("gfx1010") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1010;
+    }
+    else if(deviceString.find("gfx1011") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1011;
+    }
+    else if(deviceString.find("gfx1012") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1012;
+    }
+    else if(deviceString.find("gfx1030") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1030;
+    }
+    else if(deviceString.find("gfx1100") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1100;
+    }
+    else if(deviceString.find("gfx1101") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1101;
+    }
+    else if(deviceString.find("gfx1102") != std::string::npos)
+    {
+        return hipblasClientProcessor::gfx1102;
+    }
+    return static_cast<hipblasClientProcessor>(0);
 }
 
 int getArchMajor()
 {
-    return getArch() / 100;
-}
-
-/*******************************************************************************
- * gemm_ex int8 layout
- ******************************************************************************/
-bool layout_pack_int8(hipblasHandle_t handle)
-{
-    // This function should match the rocBLAS function: rocblas_query_int8_layout_flag
-    //
-    // Default behavior is from when int8 was supported on gfx908 and other architectures
-    // used packed_int8x4. All architectures support int8 since the following two PRs
-    // for ROCm 4.2:
-    // - Tensile PR 680
-    // - rocBLAS-internal PR 1328
-
-    hipblasInt8Datatype_t int8Type;
-    hipblasGetInt8Datatype(handle, &int8Type);
-    if(HIPBLAS_INT8_DATATYPE_DEFAULT == int8Type)
-    {
-        int arch = getArch();
-        return arch != 908;
-    }
-    else if(HIPBLAS_INT8_DATATYPE_INT8 == int8Type)
-    {
-        return false;
-    }
-    else if(HIPBLAS_INT8_DATATYPE_PACK_INT8x4 == int8Type)
-    {
-        return true;
-    }
-    return false;
+    return static_cast<int>(getArch()) / 100;
 }
 
 #ifdef __cplusplus
