@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2022 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2023 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -25,7 +25,6 @@
 #define hipblas_DATATYPE2STRING_H_
 
 #include "hipblas.h"
-#include "hipblas.hpp"
 #include <ostream>
 #include <string>
 
@@ -94,6 +93,8 @@ hipblasSideMode_t char2hipblas_side(char value);
 
 hipblasDatatype_t string2hipblas_datatype(const std::string& value);
 
+hipblasComputeType_t string2hipblas_computetype(const std::string& value);
+
 // return precision string for hipblas_datatype
 inline constexpr auto hipblas_datatype2string(hipblasDatatype_t type)
 {
@@ -106,7 +107,7 @@ inline constexpr auto hipblas_datatype2string(hipblasDatatype_t type)
     case HIPBLAS_R_64F:
         return "f64_r";
     case HIPBLAS_C_16F:
-        return "f16_k";
+        return "f16_c";
     case HIPBLAS_C_32F:
         return "f32_c";
     case HIPBLAS_C_64F:
@@ -131,10 +132,51 @@ inline constexpr auto hipblas_datatype2string(hipblasDatatype_t type)
         return "bf16_r";
     case HIPBLAS_C_16B:
         return "bf16_c";
+#ifndef HIPBLAS_V2
     case HIPBLAS_DATATYPE_INVALID:
         return "invalid";
+#endif
+    default:
+        // Missing some datatypes for hipDataType with HIPBLAS_V2. Types included
+        // here are thorough for our use cases for now, can be expanded on once hipDataType
+        // is used more regularly and is stable.
+        return "invalid";
     }
     return "invalid";
 }
 
+// return string for hipblasComputeType_t
+inline constexpr auto hipblas_computetype2string(hipblasComputeType_t type)
+{
+    switch(type)
+    {
+    case HIPBLAS_COMPUTE_16F:
+        return "c16f";
+    case HIPBLAS_COMPUTE_16F_PEDANTIC:
+        return "c16f_pedantic";
+    case HIPBLAS_COMPUTE_32F:
+        return "c32f";
+    case HIPBLAS_COMPUTE_32F_PEDANTIC:
+        return "c32f_pedantic";
+    case HIPBLAS_COMPUTE_32F_FAST_16F:
+        return "c32f_fast_16f";
+    case HIPBLAS_COMPUTE_32F_FAST_16BF:
+        return "c32f_fast_16Bf";
+    case HIPBLAS_COMPUTE_32F_FAST_TF32:
+        return "c32f_fast_tf32";
+    case HIPBLAS_COMPUTE_64F:
+        return "c64f";
+    case HIPBLAS_COMPUTE_64F_PEDANTIC:
+        return "c64f_pedantic";
+    case HIPBLAS_COMPUTE_32I:
+        return "c32i";
+    case HIPBLAS_COMPUTE_32I_PEDANTIC:
+        return "c32i_pedantic";
+    default:
+        return "invalid";
+    }
+
+    return "invalid";
+}
+
 #endif
