@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 
 # ########################################################################
-# Copyright (C) 2016-2022 Advanced Micro Devices, Inc. All rights reserved.
+# Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -22,79 +22,14 @@
 #
 # ########################################################################
 
+declare -a input_args
+input_args="$@"
+
+#use readlink rather than realpath for CentOS 6.10 support
+HIPBLAS_SRC_PATH=`dirname "$(readlink -m $0)"`
+
 /bin/ln -fs ../../.githooks/pre-commit "$(dirname "$0")/.git/hooks/"
 
-
-# #################################################
-# helper functions
-# #################################################
-function display_help()
-{
-cat <<EOF
-
-  hipBLAS library build & installation helper script.
-
-  Usage:
-    $0 (build hipblas and put library files at ./build/hipblas-install)
-    $0 <options> (modify default behavior according to the following flags)
-
-  Options:
-    --address-sanitizer           Build with address sanitizer enabled. Uses hipcc as compiler.
-
-    -b, --rocblas <version>       Specify rocblas version (e.g. 2.42.0).
-
-    -c, --clients                 Build the library clients benchmark and gtest.
-                                  (Generated binaries will be located at builddir/clients/staging)
-
-    --cuda, --use-cuda            Build library for CUDA backend.
-
-    --cudapath <cudadir>          Specify path of CUDA install (default /usr/local/cuda).
-
-    --cmake-arg                   Forward the given argument to CMake when configuring the build.
-
-    --compiler </compier/path>    Specify path to host compiler. (e.g. /opt/bin/hipcc)
-
-    --custom-target <target>      Specify custom target to link the library against (eg. host, device).
-
-    --codecoverage                Build with code coverage profiling enabled, excluding release mode.
-
-    -d, --dependencies            Build and install external dependencies. Dependecies are to be installed in /usr/local.
-                                  This should be done only once (this does not install rocBLAS, rocSolver, or cuda).
-
-    --installcuda                 Install cuda package.
-
-    --installcudaversion <version> Used with --installcuda, optionally specify cuda version to install.
-
-    -g, --debug                   Build in Debug mode, equivalent to set CMAKE_BUILD_TYPE=Debug. (Default build type is Release)
-
-    -h, --help                    Print this help message.
-
-    --hip-clang                   Build library using the hip-clang compiler.
-
-    -i, -install                  Generate and install library package after build.
-
-    -k,  --relwithdebinfo         Build in release debug mode, equivalent to set CMAKE_BUILD_TYPE=RelWithDebInfo.(Default build type is Release)
-
-    -n, --no-solver               Build hipLBAS library without rocSOLVER dependency
-
-    --no-hip-clang                Build library without using hip-clang compiler.
-
-    -p, --cmakepp                 To add CMAKE_PREFIX_PATH
-
-    -r, --relocatable             Create a package to support relocatable ROCm
-
-    --rocblas-path <blasdir>      Specify path to an existing rocBLAS install directory (e.g. /src/rocBLAS/build/release/rocblas-install).
-
-    --rocsolver-path <solverdir>  Specify path to an existing rocSOLVER install directory (e.g. /src/rocSOLVER/build/release/rocsolver-install).
-
-    -s, --static                  Build hipblas as a static library (hipblas must be built statically when the used companion rocblas is also static).
-
-    -v, --rocm-dev <version>      Specify specific rocm-dev version. (e.g. 4.5.0)
-
-    --rm-legacy-include-dir       Remove legacy include dir Packaging added for file/folder reorg backward compatibility.
-EOF
-}
-
 # This function is helpful for dockerfiles that do not have sudo installed, but the default user is root
 # true is a system command that completes successfully, function returns success
 # prereq: ${ID} must be defined before calling
@@ -231,40 +166,23 @@ install_packages( )
   local library_dependencies_centos_rhel=( "epel-release" "make" "gcc-c++" "rpm-build" )
   local library_dependencies_centos_rhel_8=( "epel-release" "make" "gcc-c++" "rpm-build" )
   local library_dependencies_fedora=( "make" "gcc-c++" "libcxx-devel" "rpm-build" )
-  local library_dependencies_sles=( "make" "gcc-c++" "libcxxtools9" "rpm-build" )
+  local library_dependencies_sles=( "make" "gcc-c++" "rpm-build" )
 
-  if [[ "${build_cuda}" == true ]]; then
+  if [[ $HIP_PLATFORM == "nvidia" ]]; then
     # Ideally, this could be cuda-cublas-dev, but the package name has a version number in it
     library_dependencies_ubuntu+=( "" ) # removed, use --installcuda option to install cuda
-  elif [[ "${build_hip_clang}" == false ]]; then
-    # Custom rocm-dev installation
-    if [[ -z ${custom_rocm_dev+foo} ]]; then
-      # Install base rocm-dev package unless -v/--rocm-dev flag is passed
-      library_dependencies_ubuntu+=( "rocm-dev" )
-      library_dependencies_centos_rhel+=( "rocm-dev" )
-      library_dependencies_centos_rhel_8=( "rocm-dev" )
-      library_dependencies_fedora+=( "rocm-dev" )
-      library_dependencies_sles+=( "rocm-dev" )
-    else
-      # Install rocm-specific rocm-dev package
-      library_dependencies_ubuntu+=( "${custom_rocm_dev}" )
-      library_dependencies_centos_rhel+=( "${custom_rocm_dev}" )
-      library_dependencies_centos_rhel_8+=( "${custom_rocm_dev}" )
-      library_dependencies_fedora+=( "${custom_rocm_dev}" )
-      library_dependencies_sles+=( "${custom_rocm_dev}" )
-    fi
-
+  else
     # Custom rocblas installation
     # Do not install rocblas if --rocblas_path flag is set,
-    # as we will be building against our own rocblas intead.
+    # as we will be building against our own rocblas instead.
     if [[ -z ${rocblas_path+foo} ]]; then
       if [[ -z ${custom_rocblas+foo} ]]; then
         # Install base rocblas package unless -b/--rocblas flag is passed
-        library_dependencies_ubuntu+=( "rocblas" )
-        library_dependencies_centos_rhel+=( "rocblas" )
-        library_dependencies_centos_rhel_8+=( "rocblas" )
-        library_dependencies_fedora+=( "rocblas" )
-        library_dependencies_sles+=( "rocblas" )
+        library_dependencies_ubuntu+=( "rocblas-dev" )
+        library_dependencies_centos_rhel+=( "rocblas-devel" )
+        library_dependencies_centos_rhel_8+=( "rocblas-devel" )
+        library_dependencies_fedora+=( "rocblas-devel" )
+        library_dependencies_sles+=( "rocblas-devel" )
       else
         # Install rocm-specific rocblas package
         library_dependencies_ubuntu+=( "${custom_rocblas}" )
@@ -278,11 +196,11 @@ install_packages( )
     # Do not install rocsolver if --rocsolver_path flag is set,
     if [[ -z ${rocsolver_path+foo} ]]; then
       if [[ "${build_solver}" == true ]]; then
-        library_dependencies_ubuntu+=( "rocsolver" )
-        library_dependencies_centos_rhel+=( "rocsolver" )
-        library_dependencies_centos_rhel_8+=( "rocsolver" )
-        library_dependencies_fedora+=( "rocsolver" )
-        library_dependencies_sles+=( "rocsolver" )
+        library_dependencies_ubuntu+=( "rocsolver-dev" )
+        library_dependencies_centos_rhel+=( "rocsolver-devel" )
+        library_dependencies_centos_rhel_8+=( "rocsolver-devel" )
+        library_dependencies_fedora+=( "rocsolver-devel" )
+        library_dependencies_sles+=( "rocsolver-devel" )
       fi
     fi
   fi
@@ -330,6 +248,11 @@ install_packages( )
 
     sles|opensuse-leap)
 #     elevate_if_not_root zypper -y update
+      if (( "${VERSION_ID%%.*}" >= "15" )); then
+        library_dependencies_sles+=( "libcxxtools10" )
+      else
+        library_dependencies_sles+=( "libcxxtools9" )
+      fi
       install_zypper_packages "${library_dependencies_sles[@]}"
       ;;
     *)
@@ -396,7 +319,7 @@ make_absolute_path( ) {
 # #################################################
 # Pre-requisites check
 # #################################################
-# Exit code 0: alls well
+# Exit code 0: all is well
 # Exit code 1: problems with getopt
 # Exit code 2: problems with supported platforms
 
@@ -418,6 +341,53 @@ fi
 # The following function exits script if an unsupported distro is detected
 supported_distro
 
+function display_help()
+{
+cat <<EOF
+
+  hipBLAS library build & installation helper script.
+
+  Usage:
+    $0 (build hipblas and put library files at ./build/hipblas-install)
+    $0 <options> (modify default behavior according to the following flags)
+
+  Options:
+
+    -b, --rocblas <version>       Specify rocblas version (e.g. 2.42.0).
+
+    -c, --clients                 Build the library clients benchmark and gtest.
+                                  (Generated binaries will be located at builddir/clients/staging)
+
+    --cmake_install               Install minimum cmake version if required.
+
+    --cuda, --use-cuda            Build library for CUDA backend (deprecated).
+                                  The target HIP platform is determined by \`hipconfig --platform\`.
+                                  To explicitly specify a platform, set the \`HIP_PLATFORM\` environment variable.
+
+    -d, --dependencies            Build and install external dependencies. Dependencies are to be installed in /usr/local.
+                                  This should be done only once (this does not install rocBLAS, rocSolver, or cuda).
+
+    --installcuda                 Install cuda package.
+
+    --installcudaversion <version> Used with --installcuda, optionally specify cuda version to install.
+
+    -g, --debug                   Build in Debug mode, equivalent to set CMAKE_BUILD_TYPE=Debug. (Default build type is Release)
+
+    -h, --help                    Print this help message.
+
+    -i, -install                  Generate and install library package after build.
+
+    -k,  --relwithdebinfo         Build in release debug mode, equivalent to set CMAKE_BUILD_TYPE=RelWithDebInfo. (Default build type is Release)
+
+    -n, --no-solver               Build hipLBAS library without rocSOLVER dependency
+
+    --rocblas-path <blasdir>      Specify path to an existing rocBLAS install directory (e.g. /src/rocBLAS/build/release/rocblas-install).
+
+    --rocsolver-path <solverdir>  Specify path to an existing rocSOLVER install directory (e.g. /src/rocSOLVER/build/release/rocsolver-install).
+
+EOF
+}
+
 # #################################################
 # global variables
 # #################################################
@@ -426,23 +396,14 @@ install_dependencies=false
 install_prefix=hipblas-install
 build_clients=false
 build_solver=true
-build_cuda=false
-build_hip_clang=true
 build_release=true
-build_relocatable=false
-build_address_sanitizer=false
 install_cuda=false
 cuda_version_install=default
 cuda_path=/usr/local/cuda
-cmake_prefix_path=/opt/rocm
 rocm_path=/opt/rocm
-compiler=g++
-build_static=false
 build_release_debug=false
-build_codecoverage=false
 update_cmake=false
-build_freorg_bkwdcomp=true
-declare -a cmake_common_options
+rmake_invoked=false
 declare -a cmake_client_options
 
 # #################################################
@@ -452,16 +413,17 @@ declare -a cmake_client_options
 # check if we have a modern version of getopt that can handle whitespace and long parameters
 getopt -T
 if [[ $? -eq 4 ]]; then
-  GETOPT_PARSE=$(getopt --name "${0}" --longoptions help,install,codecoverage,clients,no-solver,dependencies,debug,hip-clang,no-hip-clang,compiler:,cmake_install,cuda,use-cuda,cudapath:,installcuda,installcudaversion:,static,cmakepp,relocatable:,rocm-dev:,rocblas:,rocblas-path:,rocsolver-path:,custom-target:,address-sanitizer,rm-legacy-include-dir,cmake-arg: --options rhicndgp:v:b: -- "$@")
+  GETOPT_PARSE=$(getopt --name "${0}" --longoptions help,install,clients,no-solver,dependencies,debug,relwithdebinfo,cmake_install,cuda,use-cuda,installcuda,installcudaversion:,rmake_invoked,rocblas:,rocblas-path:,rocsolver-path:,address-sanitizer:, --options :rhickndgb: -- "$@")
 else
   echo "Need a new version of getopt"
   exit 1
 fi
 
-if [[ $? -ne 0 ]]; then
-  echo "getopt invocation failed; could not parse the command line";
-  exit 1
-fi
+# don't check args as rmake.py handles additional options
+# if [[ $? -ne 0 ]]; then
+#   echo "getopt invocation failed; could not parse the command line";
+#   exit 1
+# fi
 
 eval set -- "${GETOPT_PARSE}"
 
@@ -469,6 +431,10 @@ while true; do
   case "${1}" in
     -h|--help)
         display_help
+        rmake_cmd="python3 ./rmake.py --help"
+        echo "Options provied by rmake.py script:"
+        echo $rmake_cmd
+        $rmake_cmd
         exit 0
         ;;
     -i|--install)
@@ -477,9 +443,6 @@ while true; do
     -d|--dependencies)
         install_dependencies=true
         shift ;;
-    -r|--relocatable)
-        build_relocatable=true
-        shift ;;
     -c|--clients)
         build_clients=true
         shift ;;
@@ -493,53 +456,21 @@ while true; do
         build_release=false
         build_release_debug=true
         shift ;;
-    --codecoverage)
-        build_codecoverage=true
-        shift ;;
-    --hip-clang)
-        build_hip_clang=true
-        shift ;;
-    --no-hip-clang)
-        build_hip_clang=false
-        shift ;;
-    --compiler)
-        compiler=${2}
-        shift 2 ;;
     --cuda|--use-cuda)
+        # still need this flag in install.sh to support install.sh --cuda -d for now
+        echo "--cuda option is deprecated (use environment variable HIP_PLATFORM=nvidia)"
+        export HIP_PLATFORM="nvidia"
         build_cuda=true
         shift ;;
-    --cudapath)
-	cuda_path=${2}
-	export CUDA_BIN_PATH=${cuda_path}
-	shift 2 ;;
     --installcuda)
-	install_cuda=true
-	shift ;;
+      install_cuda=true
+      shift ;;
     --installcudaversion)
-	cuda_version_install=${2}
-	shift 2 ;;
-    --static)
-        build_static=true
-        shift ;;
+      cuda_version_install=${2}
+      shift 2 ;;
     --cmake_install)
         update_cmake=true
         shift ;;
-    --address-sanitizer)
-        build_address_sanitizer=true
-        compiler=hipcc
-        shift ;;
-    --rm-legacy-include-dir)
-        build_freorg_bkwdcomp=false
-        shift ;;
-    -p|--cmakepp)
-        cmake_prefix_path=${2}
-        shift 2 ;;
-    --custom-target)
-        custom_target=${2}
-        shift 2 ;;
-    -v|--rocm-dev)
-         custom_rocm_dev=${2}
-         shift 2;;
     -b|--rocblas)
          custom_rocblas=${2}
          shift 2;;
@@ -552,9 +483,11 @@ while true; do
     --prefix)
         install_prefix=${2}
         shift 2 ;;
-    --cmake-arg)
-        cmake_common_options+=("${2}")
+    --address-sanitizer)
         shift 2 ;;
+    --rmake_invoked)
+        rmake_invoked=true
+        shift ;;
     --) shift ; break ;;
     *)  echo "Unexpected command line parameter received; aborting";
         exit 1
@@ -562,18 +495,9 @@ while true; do
   esac
 done
 
-if [[ "${build_relocatable}" == true ]]; then
-    if ! [ -z ${ROCM_PATH+x} ]; then
-        rocm_path=${ROCM_PATH}
-    fi
+set -x
 
-    rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath,/opt/rocm/lib:/opt/rocm/lib64"
-    if ! [ -z ${ROCM_RPATH+x} ]; then
-        rocm_rpath=" -Wl,--enable-new-dtags -Wl,--rpath,${ROCM_RPATH}"
-    fi
-fi
-
-build_dir=./build
+build_dir=$(readlink -m ./build)
 printf "\033[32mCreating project build directory in: \033[33m${build_dir}\033[0m\n"
 
 # #################################################
@@ -588,23 +512,18 @@ else
   rm -rf ${build_dir}/debug
 fi
 
-# resolve relative paths
-if [[ -n "${rocblas_path+x}" ]]; then
-  rocblas_path="$(make_absolute_path "${rocblas_path}")"
-fi
-if [[ -n "${rocsolver_path+x}" ]]; then
-  rocsolver_path="$(make_absolute_path "${rocsolver_path}")"
-fi
-
 # Default cmake executable is called cmake
 cmake_executable=cmake
+cxx="g++"
+cc="gcc"
+fc="gfortran"
 
 # #################################################
 # dependencies
 # #################################################
 if [[ "${install_dependencies}" == true ]]; then
 
-  CMAKE_VERSION=$(cmake --version | grep -oP '(?<=version )[^ ]*' )
+  CMAKE_VERSION=$(${cmake_executable} --version | grep -oP '(?<=version )[^ ]*' )
 
   install_packages
 
@@ -616,7 +535,7 @@ if [[ "${install_dependencies}" == true ]]; then
         cd cmake-3.16.8
         ./bootstrap --prefix=/usr --no-system-curl --parallel=16
         make -j16
-        sudo make install
+        elevate_if_not_root make install
         cd ..
         rm -rf cmake-3.16.8.tar.gz cmake-3.16.8
       else
@@ -625,13 +544,13 @@ if [[ "${install_dependencies}" == true ]]; then
       fi
   fi
 
-  # The following builds googletest & lapack from source, installs into cmake default /usr/local
+  # The following builds googletest & lapack from source
   pushd .
-    printf "\033[32mBuilding \033[33mgoogletest & lapack\033[32m from source; installing into \033[33m/usr/local\033[0m\n"
+    printf "\033[32mBuilding \033[33mgoogletest & lapack\033[32m from source; installing into build tree and not default \033[33m/usr/local\033[0m\n"
     mkdir -p ${build_dir}/deps && cd ${build_dir}/deps
-    export FC="gfortran"
-    ${cmake_executable} -DCMAKE_INSTALL_PREFIX=deps-install ../../deps
+    CXX=${cxx} CC=${cc} FC=${fc} ${cmake_executable} -DCMAKE_INSTALL_PREFIX=deps-install ${HIPBLAS_SRC_PATH}/deps
     make -j$(nproc)
+    # as installing into build tree deps/deps-install rather than /usr/local won't elevate if not root
     make install
   popd
 fi
@@ -640,125 +559,69 @@ if [[ "${install_cuda}" == true ]]; then
   install_cuda_package
 fi
 
-# We append customary rocm path; if user provides custom rocm path in ${path}, our
-# hard-coded path has lesser priority
-# export PATH=${PATH}:/opt/rocm/bin
+# #################################################
+# configure & build
+# #################################################
+
+full_build_dir=""
+if [[ "${build_release}" == true ]]; then
+  full_build_dir=${build_dir}/release
+elif [[ "${build_release_debug}" == true ]]; then
+  full_build_dir=${build_dir}/release-debug
+else
+  full_build_dir=${build_dir}/debug
+fi
+
+# this can be removed and be done in rmake.py once --cuda flag support is gone
+if [[ "${build_cuda}" != true ]]; then
+  export HIP_PLATFORM="$(${rocm_path}/bin/hipconfig --platform)"
+fi
+
+if [[ "${rmake_invoked}" == false ]]; then
+  pushd .
+
+  # ensure a clean build environment
+  rm -rf ${full_build_dir}
+
+  # rmake.py at top level same as install.sh
+  python3 ./rmake.py --install_invoked ${input_args} --build_dir=${build_dir} --src_path=${HIPBLAS_SRC_PATH}
+  check_exit_code "$?"
+
+  popd
+else
+  # only dependency install supported when called from rmake
+  exit 0
+fi
+
+# #################################################
+# install
+# #################################################
+
 pushd .
-  # #################################################
-  # configure & build
-  # #################################################
 
-  if [[ "${build_static}" == true ]]; then
-    if [[ "${build_cuda}" == true ]]; then
-      printf "Static library not supported for CUDA backend.\n"
-      exit 1
-    fi
-    cmake_common_options+=("-DBUILD_SHARED_LIBS=OFF")
-    compiler="${rocm_path}/bin/hipcc" #force hipcc for static libs, g++ doesn't work
-    printf "Forcing compiler to hipcc for static library.\n"
-  fi
+cd ${full_build_dir}
 
-  # build type
-  if [[ "${build_release}" == true ]]; then
-    mkdir -p ${build_dir}/release/clients && cd ${build_dir}/release
-    cmake_common_options+=("-DCMAKE_BUILD_TYPE=Release")
-  elif [[ "${build_release_debug}" == true ]]; then
-    mkdir -p ${build_dir}/release-debug/clients && cd ${build_dir}/release-debug
-    cmake_common_options+=("-DCMAKE_BUILD_TYPE=RelWithDebInfo")
-  else
-    mkdir -p ${build_dir}/debug/clients && cd ${build_dir}/debug
-    cmake_common_options+=("-DCMAKE_BUILD_TYPE=Debug")
-  fi
-
-  # cuda
-  if [[ "${build_cuda}" == true ]]; then
-    cmake_common_options+=("-DUSE_CUDA=ON")
-  else
-    cmake_common_options+=("-DUSE_CUDA=OFF")
-  fi
-
-  # clients
-  if [[ "${build_clients}" == true ]]; then
-    cmake_client_options+=("-DBUILD_CLIENTS_TESTS=ON" "-DBUILD_CLIENTS_BENCHMARKS=ON" "-DBUILD_CLIENTS_SAMPLES=ON")
-  fi
-
-  # solver
-  if [[ "${build_solver}" == false ]]; then
-    cmake_common_options+=("-DBUILD_WITH_SOLVER=OFF")
-  fi
-
-  # sanitizer
-  if [[ "${build_address_sanitizer}" == true ]]; then
-    cmake_common_options+=("-DBUILD_ADDRESS_SANITIZER=ON")
-  fi
-
-  if [[ ${custom_target+foo} ]]; then
-    cmake_common_options+=("-DCUSTOM_TARGET=${custom_target}")
-  fi
-
-  # custom rocblas
-  if [[ ${rocblas_path+foo} ]]; then
-    cmake_common_options+=("-DCUSTOM_ROCBLAS=${rocblas_path}")
-  fi
-
-  # custom rocsolver
-  if [[ ${rocsolver_path+foo} ]]; then
-    cmake_common_options+=("-DCUSTOM_ROCSOLVER=${rocsolver_path}")
-  fi
-
-  # code coverage
-  if [[ "${build_codecoverage}" == true ]]; then
-      if [[ "${build_release}" == true ]]; then
-          echo "Code coverage is disabled in Release mode, to enable code coverage select either Debug mode (-g | --debug) or RelWithDebInfo mode (-k | --relwithdebinfo); aborting";
-          exit 1
-      fi
-      cmake_common_options+=("-DBUILD_CODE_COVERAGE=ON")
-  fi
-
-  if [[ "${build_freorg_bkwdcomp}" == true ]]; then
-    cmake_common_options+=("-DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=ON")
-  else
-    cmake_common_options+=("-DBUILD_FILE_REORG_BACKWARD_COMPATIBILITY=OFF")
-  fi
-
-  # Build library
-  if [[ "${build_relocatable}" == true ]]; then
-    CXX=${compiler} ${cmake_executable} ${cmake_common_options[@]} ${cmake_client_options[@]} -DCPACK_SET_DESTDIR=OFF -DCMAKE_INSTALL_PREFIX="${rocm_path}" \
-    -DCMAKE_PREFIX_PATH="${rocm_path};${rocm_path}/hip;$(pwd)/../deps/deps-install;${cuda_path};${cmake_prefix_path}" \
-    -DCMAKE_SHARED_LINKER_FLAGS="${rocm_rpath}" \
-    -DCMAKE_EXE_LINKER_FLAGS=" -Wl,--enable-new-dtags -Wl,--rpath,${rocm_path}/lib:${rocm_path}/lib64" \
-    -DROCM_DISABLE_LDCONFIG=ON \
-    -DROCM_PATH="${rocm_path}" ../..
-  else
-    CXX=${compiler} ${cmake_executable} ${cmake_common_options[@]} ${cmake_client_options[@]} -DCPACK_SET_DESTDIR=OFF -DCMAKE_PREFIX_PATH="$(pwd)/../deps/deps-install;${cmake_prefix_path}" -DROCM_PATH=${rocm_path} ../..
-  fi
+# installing through package manager, which makes uninstalling easy
+if [[ "${install_package}" == true ]]; then
+  make package
   check_exit_code "$?"
 
-  make -j$(nproc)
-  check_exit_code "$?"
+  case "${ID}" in
+    ubuntu)
+      elevate_if_not_root dpkg -i hipblas[-\_]*.deb
+    ;;
+    centos|rhel)
+      elevate_if_not_root yum -y localinstall hipblas-*.rpm
+    ;;
+    fedora)
+      elevate_if_not_root dnf install hipblas-*.rpm
+    ;;
+    sles|opensuse-leap)
+      elevate_if_not_root zypper -n --no-gpg-checks install hipblas-*.rpm
+    ;;
+  esac
 
-  # #################################################
-  # install
-  # #################################################
-  # installing through package manager, which makes uninstalling easy
-  if [[ "${install_package}" == true ]]; then
-    make package
-    check_exit_code "$?"
+fi
+check_exit_code "$?"
 
-    case "${ID}" in
-      ubuntu)
-        elevate_if_not_root dpkg -i hipblas[-\_]*.deb
-      ;;
-      centos|rhel)
-        elevate_if_not_root yum -y localinstall hipblas-*.rpm
-      ;;
-      fedora)
-        elevate_if_not_root dnf install hipblas-*.rpm
-      ;;
-      sles|opensuse-leap)
-        elevate_if_not_root zypper -n --no-gpg-checks install hipblas-*.rpm
-      ;;
-    esac
-
-  fi
 popd
